SystemOrganization addCategory: #ConfigurationOfGemTools!

Object subclass: #ConfigurationOfGemTools
	instanceVariableNames: 'project'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ConfigurationOfGemTools'!

!ConfigurationOfGemTools class methodsFor: 'private' stamp: 'dkh 12/8/2009 10:56'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfGemTools class methodsFor: 'private' stamp: 'dkh 1/4/2010 11:03'!
ensureMetacello
        "Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
        version of Metacello itself."

        Smalltalk at: #MetacelloProject ifAbsent: [
                Smalltalk at: #Gofer ifAbsent: [
                        "Current version of Gofer from which to bootstrap - as of 1.0-beta.15"
                        self bootstrapPackage: 'Gofer-lr.83' from: 'http://seaside.gemstone.com/ss/metacello' ].
                Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
                        gofer := goferClass new
                                url: 'http://seaside.gemstone.com/ss/metacello';
                                yourself.
                        [ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
                        gofer load ].
                "load latest version of Metacello, load a specific version if desired"
                (Smalltalk at: #ConfigurationOfMetacello) perform: #load ]

! !

!ConfigurationOfGemTools class methodsFor: 'metacello tool support' stamp: 'dkh 12/8/2009 10:56'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^self name ~= #GemToolsCommonConfiguration! !

!ConfigurationOfGemTools class methodsFor: 'loading' stamp: 'dkh 1/11/2010 11:53'!
load
	"self load"
	
	^self project latestVersion load! !

!ConfigurationOfGemTools class methodsFor: 'loading' stamp: 'dkh 1/11/2010 11:54'!
loadLatestVersion
	"self loadLatestVersion"
	
	self project updateProject.
	^self load! !

!ConfigurationOfGemTools class methodsFor: 'accessing' stamp: 'dkh 12/8/2009 10:55'!
project

	^self new project! !

!ConfigurationOfGemTools methodsFor: 'baselines' stamp: 'dkh 12/8/2009 11:01'!
baseline10beta0: spec 
	<version: '1.0-beta.0-baseline'>
	
	spec for: #squeakCommon do: [
		spec blessing: #baseline.
		spec description: 'Baseline GemTools client for Pharo/Squeak. Loads bleeding edge code.'.
		spec repository: 'http://seaside.gemstone.com/ss/GLASSClient'.
		spec
			project: 'FFI' with: [
				spec
					className: 'ConfigurationOfFFI';
					versionString: '1.0';
					file: 'ConfigurationOfFFI';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].

		spec 
			package: 'OB-SUnitGUI' with: [
				spec repository: 'http://seaside.gemstone.com/ss/obsunit' ];
			package: 'GemTools-Client' with: [
				spec requires: { 'FFI'. 'OB-SUnitGUI'. } ];
			package: 'GemTools-Platform' with: [
				spec requires: { 'GemTools-Client'. } ]].
! !

!ConfigurationOfGemTools methodsFor: 'baselines' stamp: 'dkh 1/11/2010 16:03'!
baseline10beta3: spec 
	<version: '1.0-beta.3-baseline'>
	
	spec for: #squeakCommon do: [
		spec blessing: #baseline.
		spec description: 'Use ConfigurationOfOmniBrowser to load OB if not already installed'.
		spec repository: 'http://seaside.gemstone.com/ss/GLASSClient'.
		spec
			project: 'FFI' with: [
				spec
					className: 'ConfigurationOfFFI';
					versionString: '1.0';
					file: 'ConfigurationOfFFI';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					loads: #('Core' 'OB-Shout' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Shout' with: [
				spec
					className: 'ConfigurationOfShout';
					loads: 'Core';
					file: 'ConfigurationOfShout';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.

		spec 
			package: 'OB-SUnitGUI' with: [
				spec repository: 'http://seaside.gemstone.com/ss/obsunit' ];
			package: 'GemTools-Client' with: [
				spec requires: #( 'FFI' 'OB-SUnitGUI' ) ];
			package: 'GemTools-Platform' with: [
				spec requires: #( 'GemTools-Client' ) ];
			yourself.

		spec group: 'default' with: #('OB-SUnitGUI' 'GemTools-Client' 'GemTools-Platform' ).

		spec for: #'OBNotPresent' do: [
			spec package: 'GemTools-Client' with: [
				spec requires: #( 'OB' ) ]].

		spec for: #'ShoutNotPresent' do: [
			spec package: 'GemTools-Client' with: [
				spec requires: #( 'Shout' ) ]]	]
! !

!ConfigurationOfGemTools methodsFor: 'accessing' stamp: 'dkh 1/11/2010 12:50'!
project

	| versionString projectAttributes |
	^ project ifNil: [
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		project := (Smalltalk at: #MetacelloMCProject) new.
		projectAttributes := #().
		Smalltalk at: #SystemVersion ifPresent: [:cl |
			versionString := cl current version.
			(versionString beginsWith: 'Pharo') 
				ifTrue: [
					(versionString beginsWith: 'Pharo0.1')
						ifFalse: [ projectAttributes := projectAttributes, #(#'pharo1.0Beta') ]]].
		Smalltalk at: #OBNode ifAbsent: [ projectAttributes := projectAttributes, #(#'OBNotPresent') ].
		Smalltalk at: #SHParserST80 ifAbsent: [ projectAttributes := projectAttributes, #(#'ShoutNotPresent') ].
		project projectAttributes:  projectAttributes.
		(Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear]! !

!ConfigurationOfGemTools methodsFor: 'versions' stamp: 'dkh 10/15/2009 14:43'!
version10beta0: spec
	<version: '1.0-beta.0' imports: #('1.0-beta.0-baseline' )>

	spec for: #squeakCommon do: [
		spec blessing: #beta.
		spec description: 'GemTools client for Pharo/Squeak. Initial beta.'.
		spec 
			package: 'OB-SUnitGUI' with: 'OB-SUnitGUI-dkh.52';
			package: 'GemTools-Client' with: 'GemTools-Client.experimental-dkh.495';
			package: 'GemTools-Platform' with: 'GemTools-Platform.squeakCommon-dkh.2'.].
	spec for: #'pharo1.0Beta' do: [
		spec package: 'GemTools-Platform' with: 'GemTools-Platform.pharo10beta-dkh.4'.].! !

!ConfigurationOfGemTools methodsFor: 'versions' stamp: 'dkh 11/3/2009 14:03'!
version10beta1: spec
	<version: '1.0-beta.1' imports: #('1.0-beta.0-baseline' )>

	spec for: #squeakCommon do: [
		spec blessing: #beta.
		spec description: '- Convert to using ConfigurationOfGemTools
- nicer info dialog when Undefined symbols and unsent messages are clean
- support for 3.0 GciErrSType
- change restore from backup done message ... do not prompt to start Seaside gems if Seaside is not installed
- replace dialogs that are calling "ifNotEmpty:" with: "isEmptyOrNil" (from Gerhard)
- autoAbort _before_ commands is now optional (off by default)
'.
		spec 
			package: 'OB-SUnitGUI' with: 'OB-SUnitGUI-dkh.52';
			package: 'GemTools-Client' with: 'GemTools-Client-dkh.504';
			package: 'GemTools-Platform' with: 'GemTools-Platform.squeakCommon-dkh.3'.].
	spec for: #'pharo1.0Beta' do: [
		spec package: 'GemTools-Platform' with: 'GemTools-Platform.pharo10beta-dkh.5'.].! !

!ConfigurationOfGemTools methodsFor: 'versions' stamp: 'dkh 12/2/2009 14:15'!
version10beta2: spec
	<version: '1.0-beta.2' imports: #('1.0-beta.0-baseline' )>

	spec for: #squeakCommon do: [
		spec blessing: #beta.
		spec description: '- fix update client logic to use #lastMetacelloVersionLoad
- change annotation pane and make more room for useful info
- inspect undefined and inspect sent but not implemented menu items available only when available
- clean up preferences problems when not present
- Admin>>Seaside submen available only when Seaside2.8 installed
- improve session window label (include the session name) when working with multiple stones
'.
		spec 
			package: 'OB-SUnitGUI' with: 'OB-SUnitGUI-dkh.52';
			package: 'GemTools-Client' with: 'GemTools-Client-dkh.509';
			package: 'GemTools-Platform' with: 'GemTools-Platform.squeakCommon-dkh.3'.].
	spec for: #'pharo1.0Beta' do: [
		spec package: 'GemTools-Platform' with: 'GemTools-Platform.pharo10beta-dkh.5'.].! !

!ConfigurationOfGemTools methodsFor: 'versions' stamp: 'dkh 1/11/2010 12:11'!
version10beta3: spec
	<version: '1.0-beta.3' imports: #('1.0-beta.3-baseline' )>

	spec for: #squeakCommon do: [
		spec blessing: #development.
		spec description: '- improve ''Show Object log'' output format
- add ''List backup files'' command
- add some missing icon definitions for Squeak
- load OB/Shout if not present
'.
		spec 
			project: 'Shout' with: '1.0';
			project: 'OB' with: '1.1'.
		spec 
			package: 'OB-SUnitGUI' with: 'OB-SUnitGUI-dkh.52';
			package: 'GemTools-Client' with: 'GemTools-Client-dkh.510';
			package: 'GemTools-Platform' with: 'GemTools-Platform.squeakCommon-dkh.4'.].
	spec for: #'pharo1.0Beta' do: [
		spec package: 'GemTools-Platform' with: 'GemTools-Platform.pharo10beta-dkh.5'.].
! !
